{
/*
 * Author und Copyright: Ruediger Berlich
 *
 * Distributed under the Boost Software License, Version 1.0. 
 * See http://www.boost.org/LICENSE_1_0.txt
 *
 * Run with the command "root -l Analyse.cpp" .
 * Note that the file "ageDistribution.root" must be in the current directory!
 * Requires a ROOT-version >= 6
 * Tested with ROOT 6.02.02 on MacOS X Yosemite
 */
 
  gROOT->Reset();
  gStyle->SetCanvasColor(0);
  gStyle->SetStatBorderSize(1);
  gStyle->SetOptStat(0);

  TCanvas *cc = new TCanvas("cc","cc",0,0,1024,1024);
  
  TPaveLabel* canvasTitle = new TPaveLabel(0.2,0.95,0.8,0.99, "Premium- or Fast Food-Restaurant in Karlsruhe");
  canvasTitle->Draw();

  TPad* graphPad = new TPad("Graphs", "Graphs", 0.01, 0.01, 0.99, 0.94);
  graphPad->Draw();
  graphPad->Divide(2,2);
  
  // Load the data file
  TFile *ageFile = TFile::Open("ageDistribution.root");

  // Project the NTuple "moneySpent" into a histogram
  TH1F *h18_28 = new TH1F("h18_28", "Money spent, age 18-28", 100, 0., 40.);
  TH1F *h28_38 = new TH1F("h28_38", "Money spent, age 28-38", 100, 0., 40.);
  TH1F *h38_48 = new TH1F("h38_48", "Money spent, age 38-48", 100, 0., 40.);
  TH1F *h48_58 = new TH1F("h48_58", "Money spent, age 48-58", 100, 0., 40.);
  TH1F *h58_68 = new TH1F("h58_68", "Money spent, age 58-68", 100, 0., 40.);
  TH1F *h68_78 = new TH1F("h68_78", "Money spent, age 68-78", 100, 0., 40.);
  TH1F *h78_88 = new TH1F("h78_88", "Money spent, age 78-88", 100, 0., 40.);
  TH1F *hTotal = new TH1F("hTotal", "Money spent", 100, 0., 40.);

  TH1F *meanHist = new TH1F("meanHist", "Mean values of fitted distributions", 7, 1, 7);

  // Project the NTuple data into the histograms
  moneySpent->Project("h18_28", "moneySpentLastDay", "age>=18 && age< 28");
  moneySpent->Project("h28_38", "moneySpentLastDay", "age>=28 && age< 38");
  moneySpent->Project("h38_48", "moneySpentLastDay", "age>=38 && age< 48");
  moneySpent->Project("h48_58", "moneySpentLastDay", "age>=48 && age< 58");
  moneySpent->Project("h58_68", "moneySpentLastDay", "age>=58 && age< 68");
  moneySpent->Project("h68_78", "moneySpentLastDay", "age>=68 && age< 78");
  moneySpent->Project("h78_88", "moneySpentLastDay", "age>=78 && age<=88");
  moneySpent->Project("hTotal", "moneySpentLastDay");

  // Switch to the first pad
  graphPad->cd(4);
  
  // Fit with Gauss function. Second parameter is the "mean value"
  TFitResultPtr r18_28 = h18_28->Fit("gaus", "S"); meanHist->GetXaxis()->SetBinLabel(1, "18-28");
  TFitResultPtr r28_38 = h28_38->Fit("gaus", "S"); meanHist->GetXaxis()->SetBinLabel(2, "28-38");
  TFitResultPtr r38_48 = h38_48->Fit("gaus", "S"); meanHist->GetXaxis()->SetBinLabel(3, "38-48"); 
  TFitResultPtr r48_58 = h48_58->Fit("gaus", "S"); meanHist->GetXaxis()->SetBinLabel(4, "48-58");
  TFitResultPtr r58_68 = h58_68->Fit("gaus", "S"); meanHist->GetXaxis()->SetBinLabel(5, "58-68");
  TFitResultPtr r68_78 = h68_78->Fit("gaus", "S"); meanHist->GetXaxis()->SetBinLabel(6, "68-78");
  TFitResultPtr r78_88 = h78_88->Fit("gaus", "S"); meanHist->GetXaxis()->SetBinLabel(7, "78-88");

  meanHist->Fill("18-28", r18_28->Parameter(1)); meanHist->SetBinError(1, r18_28->ParError(1));
  meanHist->Fill("28-38", r28_38->Parameter(1)); meanHist->SetBinError(2, r28_38->ParError(1));
  meanHist->Fill("38-48", r38_48->Parameter(1)); meanHist->SetBinError(3, r38_48->ParError(1));
  meanHist->Fill("48-58", r48_58->Parameter(1)); meanHist->SetBinError(4, r48_58->ParError(1));
  meanHist->Fill("58-68", r58_68->Parameter(1)); meanHist->SetBinError(5, r58_68->ParError(1));
  meanHist->Fill("68-78", r68_78->Parameter(1)); meanHist->SetBinError(6, r68_78->ParError(1));
  meanHist->Fill("78-88", r78_88->Parameter(1)); meanHist->SetBinError(7, r78_88->ParError(1));

  meanHist->GetXaxis()->SetTitle("Age range / years");
  meanHist->GetYaxis()->SetTitle("Average money spent / Euro");
  meanHist->Fit("pol4");

  // Draw the histogram
  meanHist->Draw();
  
  // Switch to the second pad
  graphPad->cd(2);
  
  // Plot the data distribution for people of all ages as well as for the 
  // group with the highest amount of money to spend
  
  hTotal->GetXaxis()->SetTitle("Amount of money spent last day / Euro");
  hTotal->GetXaxis()->SetTitleOffset(1.1);
  hTotal->GetYaxis()->SetTitle("Number of interviews");
  hTotal->GetYaxis()->SetTitleOffset(1.5);
  hTotal->Draw();
  h58_68->Draw("same");
  
  gPad->Update();
  TLine *tl1 = new TLine(r58_68->Parameter(1), 0, r58_68->Parameter(1), gPad->GetFrame()->GetY2());
  tl1->SetLineStyle(2);
  tl1->Draw();
  
  TText *t1 = new TText(5.9375, 361.934, "People of all ages");
  t1->SetTextSize(0.04);
  t1->SetTextAngle(75.6064);
  t1->Draw();
  
  TLatex *tl2 = new TLatex(18, 300, "Mean value, ages 58-68");
  tl2->SetTextSize(0.04);
  tl2->SetTextAngle(90);
  tl2->Draw();
  
  // Switch to third pad
  graphPad->cd(1);
  
  // Create a 2d-histogram for the projection of age vs. money spent
  TH2F *ageVsMoney = new TH2F("ageVsMoney", "Money spent versus age", 30, 18., 88., 30, 0., 40.);
  
  // Collect the data
  moneySpent->Project("ageVsMoney", "moneySpentLastDay:age");
  
  // Show the data
  ageVsMoney->GetXaxis()->SetTitle("Age / years");
  ageVsMoney->GetXaxis()->SetTitleOffset(1.5);
  ageVsMoney->GetYaxis()->SetTitle("Money spent / Euro");
  ageVsMoney->GetYaxis()->SetTitleOffset(1.7);
  ageVsMoney->GetZaxis()->SetTitle("Number of interviews");
  ageVsMoney->GetZaxis()->SetTitleOffset(1.6);
  ageVsMoney->Draw("SURF3");
  
  // Switch to the fourth pad
  graphPad->cd(3);
  
  // Count the number of entries for each season
  TH1F *spring = new TH1F("spring", "spring", 100, 18., 88.);
  TH1F *summer = new TH1F("summer", "summer", 100, 18., 88.);
  TH1F *fall   = new TH1F("fall",   "fall",   100, 18., 88.);
  TH1F *winter = new TH1F("winter", "winter", 100, 18., 88.);
  
  // Project the data and count the entries
  moneySpent->Project("spring", "age", "season==0."); int nSpring = spring->GetEntries();
  moneySpent->Project("summer", "age", "season==1."); int nSummer = summer->GetEntries();
  moneySpent->Project("fall",   "age", "season==2."); int nFall   = fall->GetEntries();
  moneySpent->Project("winter", "age", "season==3."); int nWinter = winter->GetEntries();
    
  // Create a histogram to plot the number of entries into
  TH1I *seasonDist = new TH1I("seasonDist", "Number of interviews per season", 4, 1, 4);
  seasonDist->GetXaxis()->SetBinLabel(1, "Spring"); seasonDist->Fill("Spring", nSpring);
  seasonDist->GetXaxis()->SetBinLabel(2, "Summer"); seasonDist->Fill("Summer", nSummer);
  seasonDist->GetXaxis()->SetBinLabel(3, "Fall");   seasonDist->Fill("Fall"  , nFall);
  seasonDist->GetXaxis()->SetBinLabel(4, "Winter"); seasonDist->Fill("Winter", nWinter);
  seasonDist->GetXaxis()->SetLabelSize(0.05);
  seasonDist->GetXaxis()->SetTitle("Season");
  seasonDist->GetYaxis()->SetLabelSize(0.03);	
  seasonDist->GetYaxis()->SetTitle("Number of interviews");
  seasonDist->GetYaxis()->SetTitleOffset(1.6);
  seasonDist->Draw("Hist");
  
  // Return home
  graphPad->cd();
  
  // Save the canvas to disk
  cc->SaveAs("premiumVsFastFood.png");
}